%parameters and data, preprocessing
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%initiate randomization!
rng('shuffle')
%wood matrix: age and corresponding m3 of wood per ha
%rows for the three woodtypes and mixed
%columns correspond to age of tree (1-42?)
%of course 42 is the answer

%parameters with uncertainty
kekm=0.2075; %0.135 to 0.28 for mound kiln
kiln_efficiency_kg=kekm+randn*(kekm/6); % normal dist
fekm=4.2;
furnace_efficiency_kg=exp(log(fekm)+log(fekm/6)*randn); %lognormal dist
%furnace_efficiency_kg=fekm+randn*(fekm/6);

convert_ha_cell=0.01;
tons_to_ha_wood=1/59;
tons_to_kg=1000;
%wood volume is given per ha, need to convert to wood volume per cell of size 10mx10m

dim1=2123;
dim2=3480;

UTM_dim1_min=4748916.6;  
UTM_dim1_max=4727687.0;
UTM_dim2_min=587273.8; 
UTM_dim2_max=622073.1; 

amountsites=size(smeltingsitedata,1);
smeltingsites=zeros(amountsites,6);
smeltingsitedata(:,1:4)=smeltingsitedata(:,1:4);
%active time
smeltingsites(:,1)=smeltingsitedata(:,1)+round(0.5*(smeltingsitedata(:,2)-smeltingsitedata(:,1)));
smeltingsites(:,2)=smeltingsitedata(:,3)+round(0.5*(smeltingsitedata(:,4)-smeltingsitedata(:,3)));
smeltingsites(:,1)=smeltingsites(:,1)+round((1/6)*randn(length(smeltingsites(:,1)),1).*smeltingsites(:,1));
smeltingsites(:,2)=smeltingsites(:,2)+round((1/6)*randn(length(smeltingsites(:,1)),1).*smeltingsites(:,2));
%barbarossa
% smeltingsites(10,1)=smeltingsitedata(10,1);
% smeltingsites(10,2)=smeltingsitedata(10,4);
%min timespan
%smeltingsites(:,1)=smeltingsitedata(:,2);
%smeltingsites(:,2)=smeltingsitedata(:,3);
%pomonte
% smeltingsites(27,1)=-130;
% smeltingsites(27,2)=-50;
%max timespan
%smeltingsites(:,1)=smeltingsitedata(:,1);
%smeltingsites(:,2)=smeltingsitedata(:,4);
%coordinates
smeltingsites(:,3)=smeltingsitedata(:,6);
smeltingsites(:,4)=smeltingsitedata(:,7);
%estimated slag
smeltingsites(:,5)=smeltingsitedata(:,8);
smeltingsites(:,6)=smeltingsitedata(:,9);

%change smeltingsites 3rd and 4th column to be indices of matrix and not
%UTM coordinates

for k=1:amountsites
    [smeltingsites(k,3), smeltingsites(k,4)]=convert_UTM_matrix(smeltingsites(k,3),smeltingsites(k,4), UTM_dim1_min,UTM_dim1_max, UTM_dim2_min,UTM_dim2_max, dim1, dim2);
end

amountsettlements=size(settlements,1);
for k=1:amountsettlements
    [settlements(k,1), settlements(k,2)]=convert_UTM_matrix(settlements(k,1), settlements(k,2), UTM_dim1_min,UTM_dim1_max, UTM_dim2_min,UTM_dim2_max, dim1, dim2);
end

stepsize=1; %year
nT=max(smeltingsites(:,2))-min(smeltingsites(:,1))+42;
saveyears=1; %save only every ten years for now

%vectors for yearly resources
yearlyslag=(mean(smeltingsites(:,5:6),2)+(1/6)*randn(length(smeltingsites(:,1)),1).*mean(smeltingsites(:,5:6),2))./((smeltingsites(:,2)-smeltingsites(:,1))+1);
totalslag=sum(yearlyslag.*((smeltingsites(:,2)-smeltingsites(:,1))+1));

yearlyore=yearlyslag*1.35;
%matrix of the amount of wood (in cubicm) needed per year and per site
yearlycharcoal=yearlyslag*tons_to_kg*furnace_efficiency_kg;
yearlywood_kg=yearlycharcoal/kiln_efficiency_kg;
yearlywood_m3=tons_to_kg*furnace_efficiency_kg*1/(kiln_efficiency_kg*wood_kg_per_cubicm)*mean(smeltingsites(:,5:6),2)./(smeltingsites(:,2)-smeltingsites(:,1));

%calculate population based on resources
population=zeros(1,nT);
hhfuel=zeros(1,nT);
hhfuel_m3=zeros(1,nT);
agriculturecells=zeros(1,nT);
pasturecells=zeros(1,nT);
forestbrowse=zeros(1,nT);
ctanimals=zeros(1,nT);

for i=1:nT
    activesites=false(1,amountsites);
    for j=1:amountsites
        if stepsize*i+min(smeltingsites(:,1))<=smeltingsites(j,2) && stepsize*i+min(smeltingsites(:,1))>=smeltingsites(j,1)
            activesites(j)=true;
        end
    end
    %workforce
    fellers=tons_to_ha_wood*sum(yearlywood_kg)/13000;
    ccburners=(sum(yearlywood_kg)/45000)*25/300;
    miners=sum(sum(yearlyore(activesites)))/23;
    smelters=(sum(yearlyslag(activesites))*0.35)/0.9;
    otransport=sum(yearlyore(activesites))/365;
    ctransport=sum(yearlycharcoal(activesites))/(5*187500);
    
    ctanimals(i)=sum(yearlycharcoal(activesites))/(187500);
    
    population(i)=fellers+ccburners+miners+smelters+ctransport+otransport;
    population(i)=1.8*population(i);
    
    hhfuel(i)=(0.25*(1/kiln_efficiency_kg)+1)*population(i);
    hhfuel_m3(i)=hhfuel(i)*1000/wood_kg_per_cubicm;
    
    ncattle=0.316*population(i);
    ngoat=1.81*population(i);
    nsheep=1.431*population(i);
    npig=0.919*population(i);
    
    %unit=cells
    pasturecells(i)=round((ncattle*0.72+ngoat*0.16+nsheep*0.07+npig*0.26+ctanimals(i)*0.9)*100);
    forestbrowse(i)=round(100*(ncattle*0.07+ngoat*0.35+nsheep*0.02));
    agriculturecells(i)=round(100*population(i)*2);
    %woodforsmeltingcells(i)=fellers*130;
    
    
end

% afintersect=zeros(2123,3480);
% for i=1:2123
%     for j=1:3480
%         if agriculture(i,j)==1
%             if vegzonesnew(i,j)>0
%                 if vegzonesnew(i,j)<5
%                     afintersect(i,j)=1;
%                 end
%             end
%         end
%         
%     end
% end
% pasture=zeros(2123,3480);
% for i=1:2123
%     for j=1:3480
%         if vegzonesnew(i,j)==5
%             pasture(i,j)=1;
%         end
%         
%     end
% end


%nan for no trees in in a grid cell of forestcells, else they give the
%mean age of the trees in a grid cells
forestcells=vegetation;
for j=1:dim1
    for i=1:dim2
        if vegetation(j,i)==0
            forestcells(j,i)=NaN;
        else
            forestcells(j,i)=42;
        end
    end
end

rotationperiod=[chestnut_1_rotation, oak_2_rotation, macchia_3_rotation, mean([chestnut_1_rotation, oak_2_rotation, macchia_3_rotation])];






%apply model to data

%forest_save=elbamodel(insideBound, forestcells, stepsize, nT, smeltingsites, yearlywood_m3, findwood_spiral, vegzonesnew, rotationperiod, woodmatrix, convert_ha_cell, '2018woodelbaspiral');